      subroutine pppvkk(ig,iwdth,u0,n0,p0,u1,n1,p1,u2,n2,p2,u,n,p,g,
     &                                                       mass,wdth)
c----------------------------------------------------------------------c
c Returns a vector array being a contraction of a quartic
c vector meson-pi0-pi+pi- coupling with a scalars u0, u1 and u2
c
c Input: ig=0(fixed coupling g)/else(running coupling g),
c        iwdth=0 - fixed width of the vector particle,
c              1,2,... - running width of the vector particle,
c        u0,u1,u2 - scalar arrays of pi0,pi+,pi-,
c        n0,n1,n2,n - numbers of polarization states,
c        p0,p1,p2 - momenta,
c        g - a quartic vector meson-pi0-pi+pi- coupling,
c        mass, wdth - mass and width of a vector particle.
c Output: u - vector array,
c         p - its momentum.
c All four momenta are cosidered as incoming to the vertex.
c
c Karol Kolodziej, University of Silesia, karol.kolodziej@us.edu.pl
c 15 Oct., 2014; modified on 28/31 Oct., 2014
c 12 March, 2015 (call to subroutine runwidth added)
c 19 March, 2015 (call to subroutine runwidth changed,
c                 call to subroutine runcoupl implemented)
c----------------------------------------------------------------------c

      implicit none

      integer, parameter :: dp=kind(1.d0)
      integer :: ig,iwdth,n0,n1,n2,n,i0,i1,i2,i

      real(dp) :: mass,wdth
      real(dp), dimension(0:3) :: p0,p1,p2,p
      complex(dp) :: u0(1,n0),u1(1,n1),u2(1,n2),u(0:3,n),g,rg,gden,mv2,
     &               r(0:3)

      p=-p0-p1-p2

      if (ig == 0) then
       rg=g
      else
       call runcoupl(ig,p,rg)
      end if

      if (mass > 0.d0) then
       if (iwdth == 0) then
        mv2=cmplx(mass**2,-mass*wdth,dp)
       else
        call runwidth(iwdth,p,mass,wdth,mv2)
       end if
       gden=-rg/(cmplx(p(0)**2-p(1)**2-p(2)**2-p(3)**2,0.d0,dp)-mv2)
      else
       gden=-rg/cmplx(p(0)**2-p(1)**2-p(2)**2-p(3)**2,0.d0,dp)
      end if

      r=(/cmplx(-(p0(1)*(p1(2)*p2(3)-p1(3)*p2(2))
     &           -p0(2)*(p1(1)*p2(3)-p1(3)*p2(1))
     &           +p0(3)*(p1(1)*p2(2)-p1(2)*p2(1))),0.d0,dp),
     &    cmplx( -p0(0)*(p1(2)*p2(3)-p1(3)*p2(2))
     &           +p0(2)*(p1(0)*p2(3)-p1(3)*p2(0))
     &           -p0(3)*(p1(0)*p2(2)-p1(2)*p2(0)),0.d0,dp),
     &    cmplx(  p0(0)*(p1(1)*p2(3)-p1(3)*p2(1))
     &           -p0(1)*(p1(0)*p2(3)-p1(3)*p2(0))
     &           +p0(3)*(p1(0)*p2(1)-p1(1)*p2(0)),0.d0,dp),
     &    cmplx( -p0(0)*(p1(1)*p2(2)-p1(2)*p2(1))
     &           +p0(1)*(p1(0)*p2(2)-p1(2)*p2(0))
     &           -p0(2)*(p1(0)*p2(1)-p1(1)*p2(0)),0.d0,dp)/)


      i=0
      do i2=1,n2
       do i1=1,n1
        do i0=1,n0
         i=i+1
         u(:,i)=gden*u0(1,i0)*u1(1,i1)*u2(1,i2)*r
c Test of gauge invariance
c          u(:,i)=u(:,i)-(p(0)*u(0,i)-p(1)*u(1,i)
c     &                 -p(2)*u(2,i)-p(3)*u(3,i))*p*1.d16
         if (mass > 0.d0) then
          u(:,i)=u(:,i)-(p(0)*u(0,i)-p(1)*u(1,i)
     &                 -p(2)*u(2,i)-p(3)*u(3,i))*p/mv2
         end if
        end do
       end do
      end do

      end subroutine pppvkk
