      subroutine vpppmd(ig,ip,g,uv,pv,u1,p1,u2,p2,u,mat)
c----------------------------------------------------------------------c
c Returns a matrix element for a quartic vector meson-pi0-pi+pi- 
c coupling with a vector uv and scalars u1,u2,u
c
c Input: ig=0(fixed coupling g)/else(running coupling g),
c        ip = +1, if u represents pi+,
c        ip = -1, if u represents pi0 or pi-,
c        g - a quartic vector meson-pi0-pi+pi- coupling,
c        uv - vector array,
c        u1,u2 - scalar arrays,
c        pv,p1,p2 - momenta.
c Output: mat - the matrix element.
c All four momenta are cosidered as incoming to the vertex.
c
c Karol Kolodziej, University of Silesia, karol.kolodziej@us.edu.pl
c 15 Oct., 2014; modified on 30 Oct., 2014;
c 19 March, 2015 (call to subroutine runcoupl implemented)
c 6 April, 2015:
c an extra minus sign, resulting from missing i^2 if a quartic coupling 
c is present, introduced
c----------------------------------------------------------------------c

      implicit none

      integer, parameter :: dp=kind(1.d0)
      integer :: ig,ip

      real(dp), dimension(0:3) :: pv,p1,p2,p
      complex(dp) :: uv(0:3),u1(1),u2(1),u(1),g,rg,mat,r(0:3)

      p=-pv-p1-p2

      if (ig == 0) then
       rg=g
      else
       call runcoupl(ig,p,rg)
      end if

      r=(/cmplx(-(p1(1)*(p2(2)*p(3)-p2(3)*p(2))
     &           -p1(2)*(p2(1)*p(3)-p2(3)*p(1))
     &           +p1(3)*(p2(1)*p(2)-p2(2)*p(1))),0.d0,dp),
     &    cmplx( -p1(0)*(p2(2)*p(3)-p2(3)*p(2))
     &           +p1(2)*(p2(0)*p(3)-p2(3)*p(0))
     &           -p1(3)*(p2(0)*p(2)-p2(2)*p(0)),0.d0,dp),
     &    cmplx(  p1(0)*(p2(1)*p(3)-p2(3)*p(1))
     &           -p1(1)*(p2(0)*p(3)-p2(3)*p(0))
     &           +p1(3)*(p2(0)*p(1)-p2(1)*p(0)),0.d0,dp),
     &    cmplx( -p1(0)*(p2(1)*p(2)-p2(2)*p(1))
     &           +p1(1)*(p2(0)*p(2)-p2(2)*p(0))
     &           -p1(2)*(p2(0)*p(1)-p2(1)*p(0)),0.d0,dp)/)

      mat=-ip*rg*u(1)*u1(1)*u2(1)*(uv(0)*r(0)
     &          -uv(1)*r(1)-uv(2)*r(2)-uv(3)*r(3))

      end subroutine vpppmd
