      subroutine parfixkk
c----------------------------------------------------------------------c
c Returns some SM paprameters
c
c Karol Kolodziej, University of Silesia, kolodzie@us.edu.pl
c 21 March, 2006; modified on
c 6 April, 2011: formula for calculating gamtsm0 changed such that is 
c                valid for the complex mass scheme; 
c                anomalous wtb coupling fixed to wff if iwtb=0, in case 
c                the user forgets to change the coupling in vertices.dat
c 6 May, 2013: Complex mass of the top quark transfered through 
c the anomalous Wtb coupling.
c 3 Dec., 2013: missing "if" command, which resulted in termination of 
c the program for processes without partons in the initial state,
c supplemented.
c 14 March, 2014: new parameter inwtb introduced, so that the anomalous 
c Wtb can be included only if code was generated with iwtb=1 in 
c carlomat.f
c 26 June, 2014: modification of 14 March, 2014 corrected
c----------------------------------------------------------------------c

      use mathprms 
      use inprms
      use drivekk
      use couplsmkk
      use partcls
      use topan
      use prtinds

      implicit none

      integer :: i,nlept,ianti(2),nprt

      real(dp) :: rwt,gwt,gamw0,gamhff,gamhbb,
     &            gamhwff,ewh,gamhzff,ezh,betath,gamhsm0,lamsq,
     &            xpdf(-6:6),xphoton

c      real(dp) :: mf(3,4),gamf(3,4),mv(0:4),gamv(0:4)

      complex(dp) :: cmw,cmh,mh2,ma2,mw2,mz2
ckk>
      real(dp) :: gamwsm0,gamtsm0,gamtsm,gamt3,x(2)
ckk<

c Fix quark masses other than mt:

      mu=mu0 
      md=md0 
      ms=ms0 
      mc=mc0 
      mb=mb0 

ckk_had>
      if (ihad > 0) then
       if (ipdf == 1) then
        call GetAllPDFsAlt(prefix,iset,1.d-3,1.d1,xpdf,xphoton)
       call mstw_interface
       else if (ipdf == 2) then
        call SetCtq6(iset)
        call ctq6f_interface(iset)
       else
        write(*,*)'parfixkk: ipdf=',ipdf,' is not supported'
       end if
      end if
ckk_had<
c Coupling constants:

      e0=sqrt(4.d0*pi/ialph0)
      ew=sqrt(4.d0*pi/ialphw)
      eo=sqrt(4.d0*pi/ialpho)
      es=sqrt(4.d0*pi*alphas)

c W boson width to lowest order of SM:

      gamwsm0=zero
      call wwidth(zero,me,mw,one,one,ew,sw2,gamw0)
      gamwsm0=gamwsm0+gamw0
      call wwidth(zero,mmu,mw,one,one,ew,sw2,gamw0)
      gamwsm0=gamwsm0+gamw0
      call wwidth(zero,mtau,mw,one,one,ew,sw2,gamw0)
      gamwsm0=gamwsm0+gamw0
      call wwidth(mu,md,mw,ncol,one,ew,sw2,gamw0)
      gamwsm0=gamwsm0+gamw0
      call wwidth(mc,ms,mw,ncol,one,ew,sw2,gamw0)
      gamwsm0=gamwsm0+gamw0

      if (gamw == 0.d0) then
       gamw=gamwsm0
      end if

cc The SM Higgs width:

c H -> ff~:

      gamhff=sqrt(2.d0)*gmu/(8.d0*pi)*mh
     &      *(me**2*(sqrt(1.d0-4.d0*(me/mh)**2))**3
     &       +mmu**2*(sqrt(1.d0-4.d0*(mmu/mh)**2))**3
     &       +mtau**2*(sqrt(1.d0-4.d0*(mtau/mh)**2))**3
     & +ncol*(mu**2*(sqrt(1.d0-4.d0*(mu/mh)**2))**3
     &       +md**2*(sqrt(1.d0-4.d0*(md/mh)**2))**3
     &       +mc**2*(sqrt(1.d0-4.d0*(mc/mh)**2))**3
     &       +ms**2*(sqrt(1.d0-4.d0*(ms/mh)**2))**3
     &       +mb**2*(sqrt(1.d0-4.d0*(mb/mh)**2))**3))

      gamhbb=sqrt(2.d0)*gmu/(8.d0*pi)*mh
     &       *ncol*mb**2*(sqrt(1.d0-4.d0*(mb/mh)**2))**3

      if (mh > 2.d0*mt) then
       betath=1.d0-4.d0*(mt/mh)**2
       gamhff=gamhff+sqrt(2.d0)*gmu/(8.d0*pi)*mh
     &       *ncol*mt**2*(sqrt(betath))**3
      end if


c H -> Wff'~

      ewh=mw/mh

      gamhwff=3.d0*(4.d0*sqrt(2.d0)*gmu*mw**2)**2/(512.d0*pi**3)*mh
     &       *f(ewh)

      ezh=mz/mh

      gamhzff=(4.d0*sqrt(2.d0)*gmu*mw**2)**2/(2048.d0*pi**3*(mw/mz)**4)
     &       *mh*(7.d0-40.d0/3.d0*sw2+160.d0/9.d0*sw2**2)*f(ezh)

      gamhsm0=gamhff+gamhwff+gamhzff

      if (gamh == 0.d0) then
       gamh=gamhsm0
      end if

c Complex masses squared:

      mw2=cmplx(mw**2,-mw*gamw,dp)
      ma2=cmplx(zero,zero,dp)
      mz2=cmplx(mz**2,-mz*gamz,dp)

      if (ischeme == 1) then
       csw2=(mz2-mw2)/mz2
       cmw=sqrt(mw2)
      else
       csw2=cmplx(sw2,0.d0,dp)
       cmw=cmplx(mw,0.d0,dp)
      end if


c The SM top width:

c---- total:

      gamtsm0=gmu*mt**3/(8.d0*pi*sqrt(2.d0))
     &       *(1.d0-(mw/mt)**2)**2*(1.d0+2.d0*(mw/mt)**2)

      gamtsm=gmu*mt**3/(8.d0*pi*sqrt(2.d0))
     &      *(1.d0-(mw/mt)**2)**2*(1.d0+2.d0*(mw/mt)**2)
     &      *(1.d0-2.d0*alphas/(3.d0*pi)*(2.d0*pi**2/3.d0-5.d0/2.d0))

c Including a nonzero bottom quark mass:

c      gamtsm0=sqrt(lamsq(mt,mb,mw))/(16.d0*sw2*ialphw*mt**3)
c     &       *(mt**2+mb**2-2.d0*mw**2+((mt-mb)*(mt+mb)/mw)**2)
      gamtsm0=sqrt(lamsq(mt,mb,mw))/(16.d0*abs(csw2)*ialphw*mt**3)
     &       *(mt**2+mb**2-2.d0*mw**2+((mt-mb)*(mt+mb)/mw)**2)

c Fix the top quark width:
      wff=(/ocom,ew/sqrt(2.d0*csw2)/)
      if (inwtb == 1) then
       x(1)=0.5d0
       x(2)=0.d0
c Anomalous wtb coupling, see K. Kolodziej, Phys. Lett. B584 (2004) 89,
c hep-ph/0312168
c t -> b w+, Eq.(4):
       wtb(1,1)=wff(2)*f1p 
       wtb(2,1)=wff(2)*f1m
       wtb(1,2)=wff(2)*f2p/mw
       wtb(2,2)=wff(2)*f2m/mw
c t~ -> b~ w-, Eq.(5):
       if (iwtb == 1) then      ! CP even, conditions Eq. (6) satisfied:
        wtb(1,3)=wtb(1,1)
        wtb(2,3)=wtb(2,1)
        wtb(1,4)=wtb(2,2)
        wtb(2,4)=wtb(1,2)
       else if (iwtb == 2) then ! CP odd:
        wtb(1,3)=wff(2)*f1bp
        wtb(2,3)=wff(2)*f1bm
        wtb(1,4)=wff(2)*f2bp/mw
        wtb(2,4)=wff(2)*f2bm/mw
       else ! code generated with iwtb=1, but now iwtb=0
        wtb(:,1)=wff
        wtb(:,2)=ocom
        wtb(:,3)=wff
        wtb(:,4)=ocom
        if (gamt == 0.d0) then
         gamt=gamtsm0
        end if
       end if
       call gamtopan(x)
c Complex mass of the top quark transfered through the anomalous Wtb coupling:
       if (iwtb == 2) then
        wtb(1,5)=cmplx(mt**2,-mt*gamt,dp)
        wtb(2,5)=cmplx(mt**2,-mt*gmtb,dp)
       else
        wtb(:,5)=cmplx(mt**2,-mt*gamt,dp)
       end if
       if (ickm == 1) then
        wtb(:,:4)=wtb(:,:4)*V_tb
       end if
      else
       wtb(:,1)=wff         ! Added on 26 June, 2014
       wtb(:,2)=ocom
       wtb(:,3)=wff
       wtb(:,4)=ocom
       if (gamt == 0.d0) then
        gamt=gamtsm0
       end if
      end if

c---- partial (t -> b l+ vl)

      rwt=mw/mt
      gwt=gamw/mt

      gamt3=gmu**2*mt**3*mw**2/(96.d0*pi**3)
     &     *((1.d0-3.d0*rwt**4+2.d0*rwt**6+3.d0*rwt**2*gwt**2
     &       -6.d0*rwt**4*gwt**2)*mw/gamw*(pi
     &       -atan(mt**2*gamw/(mw*(mt**2-mw**2-gamw**2))))
     &      +(3.d0*rwt**4-3.d0*rwt**6+rwt**4*gwt**2)
     &  *log(mw**2*(mw**2+gamw**2)/((mt**2-mw**2)**2+mw**2*gamw**2)))


c Complex masses squared:

      mh2=cmplx(mh**2,-mh*gamh,dp)

      if (ischeme == 1) then
        cmh=sqrt(mh2)
      else
        cmh=cmplx(mh,0.d0,dp)
      end if

c Arbitrary weights for the Born cross section: aw0(1)+...+aw0(nkin)=1

      aw0=1.d0/dble(nkin)

c Couplings:

      if (ialpha == 0) then
       call couplsm(e0,cmw,cmh)
      else if (ialpha == 1) then
       call couplsm(ew,cmw,cmh)
      else if (ialpha == 2) then
       call couplsm(eo,cmw,cmh)
      else
       write(*,*)'parfixkk: This choice of iaplha is not possible',
     &            ialpha
       stop
      end if

c External particles:

      include 'partcls.dat'

c If there is no partons in the initial state then set ihad to 0:

      nprt=0
      do i=1,nisp
       if (expl(i) == 'q' .or. expl(i) == 'g') nprt=nprt+1
      end do
      if (nprt == 0) ihad=0

      ianti=0

      if (ihad > 0) then    ! Added on 3 Dec. 2013
       do i=1,2
        ianti(i)=index(expc(i),'~')
        if (trim(expc(i)) == 'g') then
         ipart(i)=0
        else if (expc(i)(1:1) == 'd') then
         ipart(i)=1
         if (ipdf == 2) ipart(i)=2
        else if (expc(i)(1:1) == 'u') then
         ipart(i)=2
         if (ipdf == 2) ipart(i)=1
        else if (expc(i)(1:1) == 's') then
         ipart(i)=3
        else if (expc(i)(1:1) == 'c') then
         ipart(i)=4
        else if (expc(i)(1:1) == 'b') then
         ipart(i)=5
        else
         write(*,*) 'parfikk:',trim(expc(i)),' is not a parton'
         stop
        end if
       end do

       if (ihad == 1) then         ! proton-anti-proton scattering
        if (ianti(1) > 0) then
         if (ianti(2) > 0) ipart(2)=-ipart(2)
        else
         if (ipart(1) /= 0 .and. ianti(2) == 0) ipart(2)=-ipart(2)
        end if
       else if (ihad == 2) then     ! proton-proton scattering
        if (ianti(1) > 0) ipart(1)=-ipart(1)
        if (ianti(2) > 0) ipart(2)=-ipart(2)
       else
        write(*,*) 'parfikk: ihad =',ihad,' not implemented'
        stop
       end if
      end if      ! Added on 3 Dec. 2013

      ralpw0=1.d0

      do i=1,nepl
       if (expl(i) == 'a') then
        if (ialpha == 1) then
         ralpw0=ralpw0*ialphw/ialph0
        else if (ialpha == 2) then
         ralpw0=ralpw0*ialpho/ialph0
        end if
       end if
      end do
c Determine numbers of the final state particles of different kind and
c their indices to be referenced in cut routines
      nxn=0  ! neutrinos
      nxl=0  ! charged leptons
      nxq=0  ! quarks /= b
      nxb=0  ! b-quarks
      nxa=0  ! photons
      nxg=0  ! gluons
      nxs=0  ! pions
      nxj=0  ! light quark or gluon
      nxp=0  ! protons
      ixn=0
      ixl=0
      ixq=0
      ixb=0
      ixa=0
      ixg=0
      ixs=0
      ixj=0
      ixn=0
      ixp=0
      iyl=0
      iyq=0
      iyb=0
      iya=0
      iyg=0
      iys=0
      iyj=0
      iyp=0
      do i=nisp+1,nepl
       if (expl(i) == 'n') then
        nxn=nxn+1
        ixn(nxn)=i
        iyn(i)=i
       else if (expl(i) == 'l') then
        nxl=nxl+1
        ixl(nxl)=i
        iyl(i)=i
       else if (expl(i) == 'q' .and. expc(i)(1:1) /= 'b') then
        nxq=nxq+1
        ixq(nxq)=i
        iyq(i)=i
       else if (expc(i)(1:1) == 'b') then
        nxb=nxb+1
        ixb(nxb)=i
        iyb(i)=i
       else if (expl(i) == 'a') then
        nxa=nxa+1
        ixa(nxa)=i
        iya(i)=i
       else if (expl(i) == 'g') then
        nxg=nxg+1
        ixg(nxg)=i
        iyg(i)=i
       else if (expl(i) == 's') then
        nxs=nxs+1
        ixs(nxs)=i
        iys(i)=i
       else if (trim(expc(i)) == 'p' .or. trim(expc(i)) == 'p~') then
        nxp=nxp+1
        ixp(nxp)=i
        iyp(i)=i
       end if
       if ((expl(i) == 'q' .and. expc(i)(1:1) /= 'b') .or.
     &                                    expl(i) == 'g') then
        nxj=nxj+1
        ixj(nxj)=i
        iyj(i)=i
       end if
      end do

c Top quark pair production and decay into semileptonic final state:
c Find the final state lepton 'ilept', its charge 'lchrg' and the final state
c neutrino 'ineut'
      nlept=0
      ilept=0
      lchrg=0
      ineut=0
      do i=nisp+1,nepl
       if (expl(i) == 'l') then
        nlept=nlept+1
        ilept=i
        if (index(expc(i),'+') > 0) then
         lchrg=1
        else
         lchrg=-1
        end if
       end if
       if (expl(i) == 'n') then
        ineut=i
       end if
      end do
      if (nlept == 0) then
       write(*,*) 'parfixkk: No charged leptons in the process.'
      else if (nlept > 1) then
       write(*,*) 
     & 'parfixkk: More than one charged lepton in the process.'
      end if
c Find the final state b-quark 'ibqrk' from the same top quark decay as 
c the lepton 
      ibqrk=0
      do i=nisp+1,nepl
       if (lchrg == -1) then
        if (expc(i)(1:2) == 'b~') then
         ibqrk=i
         exit
        end if
       else if (lchrg == 1) then
        if (expc(i)(1:1) == 'b') then
         ibqrk=i
         exit
        end if
       end if
      end do

      contains
       function f(eps)
       real(dp) :: f,eps
 
        f=3.d0*(1.d0-8.d0*eps**2+20.d0*eps**4)
     &   /sqrt(4.d0*eps**2-1.d0)*acos((3.d0*eps**2-1.d0)/(2.d0*eps**3))
     &   -(1.d0-eps**2)*(23.5d0*eps**2-6.5d0+1.d0/eps**2)
     &   -3.d0*(1.d0-6.d0*eps**2+4.d0*eps**4)*log(eps)

       end function f

      end subroutine parfixkk
